#ifndef SERVERCONFIGDIALOG_H
#define SERVERCONFIGDIALOG_H

#include <kdialogbase.h>

class QLineEdit;

class ServerConfigDialog : public KDialogBase
{
    Q_OBJECT
  public:
    ServerConfigDialog( QWidget *parent = 0 , const char *name = 0 );

    void setServer( const QString &name, const QString &url );

    QString serverName();
    QString serverUrl();
        
  private:
    QLineEdit *mServerName;
    QLineEdit *mServerUrl;
};

#endif
